/**
 * apeman app to send response.
 * @function apemanAppSend
 * @param {object} [options] - Optional settings.
 * @param {string} [options.name='send'] - Name of property for request.
 * @returns {function} - Defined app function.
 */

'use strict'

const debug = require('debug')('apeman:app:send')

/** @lends create */
function create (options = {}) {
  let name = options.name || 'send'

  debug(`Register send to req.${name}`)

  /**
   * Defined app.
   * @function app
   * @param {object} req - Request object.
   * @param {object} res - Response object.
   * @param {function} next - Pass to next handler.
   */
  function app (req, res, next) {
    if (!req.hasOwnProperty('format')) {
      throw new Error('req.format not found. Use "apeman-app-format" before this.')
    }

    function send (data, format) {
      format = format || req.format
      let isValid = res[ format ] && typeof (res[ format ]) === 'function'
      if (isValid) {
        res[ format ](data)
      } else {
        throw new Error(`req.${format} not found. Try "apeman-app-${format}" or some other middlewares.`)
      }
    }

    res[ name ] = res[ name ] || send

    next()
  }

  // Description of this app.
  Object.assign(app, {
    $desc: 'Add function to send response.'
  })
  return app
}

module.exports = create
