/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const apemanport = require('apemanport')
const co = require('co')
const assert = require('assert')
const apemanApp = require('apeman-app')
const apemanrequest = require('apemanrequest')

describe('create', () => {
  let server, baseUrl
  let request = apemanrequest.create({})
  before(() => co(function * () {
    let port = yield apemanport.find()

    let app = create({})
    assert.ok(app)

    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              require('apeman-app-format')(),
              require('apeman-app-json')(),
              app,
              (req, res, next) => {
                res.send({
                  foo: 'bar'
                })
              }
            ]
          }
        }
      }
    })
    baseUrl = `http://localhost:${port}`
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create an app.', () => co(function * () {
    let res = yield request({
      method: 'GET',
      url: `${baseUrl}/foo.json`,
      json: true
    })
    let { body } = res
    assert.equal(res.statusCode, 200)
    assert.deepEqual(body, {
      'foo': 'bar'
    })
  }))
})

/* global describe, before, after, it */
